@@ -4,6 +4,7 @@ from quick_resto_API.quick_resto_objects.modules.front.terminal import Terminal
 from quick_resto_API.quick_resto_objects.modules.front.shift import Shift
 from quick_resto_API.quick_resto_objects.modules.personnel.employee import Employee
 from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObject
+from quick_resto_API.quick_resto_objects.modules.warehouse.sale_place import SalePlace
 
 
 class OrderInfo(QuickRestoObject):
@@ -75,6 +76,10 @@ class OrderInfo(QuickRestoObject):
     def original_order_doc_id(self) -> str:
         return self._original_order_doc_id
 
+    @property
+    def create_terminal_sale_place(self) -> SalePlace:
+        return self._create_terminal_sale_place
+
     @property
     def precheck_doc_id(self) -> str:
         return self._precheck_doc_id
@@ -124,7 +129,7 @@ class OrderInfo(QuickRestoObject):
                  front: dict = None, frontSum: float = None, frontTotalAbsoluteCharge: float = None,
                  frontTotalAbsoluteDiscount: float = None, frontTotalBonuses: float = None,
                  frontTotalCard: float = None, frontTotalCashMinusDiscount: float = None, frontTotalDiscount: float = None,
-                 frontTotalPrice: float = None,
+                 frontTotalPrice: float = None, createTerminalSalePlace:dict = None,
                  kkmTerminalName: str = None, originalOrderDocId: str = None, precheckDocId: str = None,
                  reopenedOrderDocId: str = None, returned: bool = None,
                  returnOrderDocId: str = None, shift: dict = None, shiftId: str = None, tableScheme: dict = None,
@@ -151,6 +156,11 @@ class OrderInfo(QuickRestoObject):
         else:
             self._front = None
 
+        if createTerminalSalePlace is not None:
+            self._create_terminal_sale_place = SalePlace(**createTerminalSalePlace)
+        else:
+            self._create_terminal_sale_place = None
+
         self._front_sum: float = frontSum
         self._front_total_absolute_charge: float = frontTotalAbsoluteCharge
         self._front_total_absolute_discount: float = frontTotalAbsoluteDiscount
